@@ -2,9 +2,9 @@ from __future__ import annotations
 
 import dataclasses
 import re
-import typing
+from typing import TYPE_CHECKING, Any
 
-if typing.TYPE_CHECKING:
+if TYPE_CHECKING:
     from cappa.arg import Arg
 
 
@@ -13,12 +13,7 @@ class ShellHandler:
     name: str
     template: str
 
-    def backend_template(self, prog: str, arg: Arg) -> str:
-        try:
-            prog, _ = prog.rsplit("/", 1)
-        except ValueError:
-            pass
-
+    def backend_template(self, prog: str, arg: Arg[Any]) -> str:
         safe_name = re.sub(r"\W*", "", prog.replace("-", "_"), flags=re.ASCII)
 
         assert isinstance(arg.long, list)
@@ -34,16 +29,16 @@ class ShellHandler:
 class Completion:
     value: str | None = None
     help: str | None = None
+    arg: Arg[Any] | None = None
+
+    @property
+    def description(self) -> str:
+        if not self.arg or self.arg.help:
+            return self.help or ""
+
+        return f"<{self.arg.value_name}> {self.help}".strip()
 
 
 @dataclasses.dataclass
 class FileCompletion:
     text: str
-
-
-class CompletionError(RuntimeError):
-    def __init__(
-        self, *completions: Completion | FileCompletion, value="complete", **_
-    ) -> None:
-        self.completions = completions
-        self.value = value
